# [PySiddhi](https://siddhi-io.github.io/PySiddhi/)

***PySiddhi*** is a Python wrapper for [Siddhi](https://siddhi-io.github.io/siddhi/). Which can listens to events from data streams, detects complex conditions
described via a ***Streaming SQL language***, and triggers actions. It performs both ***Stream Processing*** and 
***Complex Event Processing*** on streaming data. Its Siddhi core is written in Java library. 

- PySiddhi wraps [Siddhi 5](https://siddhi-io.github.io/siddhi/)

## Features

- [x] Basic functionality of Siddhi 5.x.x
- [x] Siddhi Debugger
- [x] Support to Siddhi Extensions Loading

For a Quick Demo and documentation refer [PySiddhi Site](https://siddhi-io.github.io/PySiddhi/)

## Contribution 

_PySiddhi is initiated by a project for Google Summer of Code 2017 Program._

Contributed by: __Madhawa Vidanapathirana__
Email: madhawavidanapathirana@gmail.com
Organization: University of Moratuwa, Sri Lanka.

## Support and Contribution

* We encourage users to ask questions and get support via <a target="_blank" href="https://stackoverflow.com/questions/tagged/siddhi">StackOverflow</a>, make sure to add the `siddhi` tag to the issue for better response.

* If you find any issues related to the extension please report them on <a target="_blank" href="https://github.com/siddhi-io/siddhi-execution-string/issues">the issue tracker</a>.

* For production support and other contribution related information refer <a target="_blank" href="https://siddhi.io/community/">Siddhi Community</a> documentation.
